@@ -14,22 +14,25 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from PySide import QtGui, QtCore
+from calculate.consolegui import qt
 from more import ButtonMenu, icon_visible, LabelWordWrap, get_sid, show_msg, \
-                 ClientServiceThread, show_question, get_view_params, _print
+                 ClientServiceThread, show_question, get_view_params, _print, \
+    get_system_rgb
 
-class StepLabel(QtGui.QLabel):
-    clicked = QtCore.Signal()
+
+class StepLabel(qt.QLabel):
+    clicked = qt.Signal()
     def __init__(self, text, parent):
-        QtGui.QLabel.__init__(self, parent)
+        qt.QLabel.__init__(self, parent)
         self.setWordWrap(True)
         self.setText(text)
         self.updateGeometry()
-#        self.setCursor(QtCore.Qt.CursorShape.PointingHandCursor)
+        self.setCursor(qt.Qt.PointingHandCursor)
+        bg = get_system_rgb(parent._parent, qt.QPalette.Highlight)
         self.setStyleSheet("QLabel {margin-left: 0px; margin-right: 0px;}"
                             "QLabel:hover {"#color: blue;"
 #                           "QLabel:hover {color: white;"
-                           "background-color: #D4D4D4;}")
+                           "background-color: %s;}"%bg)
         self.setContentsMargins(26,0,26,0)
         self.adjustSize()
         self.setFixedHeight(self.height() + 13)
@@ -42,9 +45,9 @@ class StepLabel(QtGui.QLabel):
         font.setBold(bold)
         self.setFont(font)
 
-class LeftMenu(QtGui.QScrollArea):
+class LeftMenu(qt.QScrollArea):
     def __init__(self, parent, ClientObj):
-        QtGui.QScrollArea.__init__(self, parent)
+        qt.QScrollArea.__init__(self, parent)
         self._parent = parent
         self.ClientObj = ClientObj
 
@@ -53,32 +56,32 @@ class LeftMenu(QtGui.QScrollArea):
 #        self.setStyleSheet("QWidget { background-color: rgb (%s) ;}" \
 #                         %ClientObj.method_background_color.replace(' ',',',2))
         # Set style
-        self.setStyleSheet("QScrollArea {"# D6D2D0
-#                           "background-color: #EEEEEE;"
-                           "background-color: qlineargradient("
-                           "x1: 0, y1: 0, x2: 0, y2: 1, "
-                           "stop: 0 #EEEEEE, stop: 0.8 #EEEEEE, "
-                           "stop: 1 #E4E1E0);"
-
-#                           "border: 4px solid red;"
-                           "border-right: 1px solid qlineargradient("
-                           "x1: 0, y1: 0, x2: 0, y2: 1, "
-                           "stop: 0 #A8A3A0, stop: 0.8 #A8A3A0, "
-                           "stop: 0.95 transparent, stop: 1 transparent);"
-#                           "border-bottom-color: qlineargradient("
+#        self.setStyleSheet("QScrollArea {"# D6D2D0
+##                           "background-color: #EEEEEE;"
+#                           "background-color: qlineargradient("
 #                           "x1: 0, y1: 0, x2: 0, y2: 1, "
-#                           "stop: 0 transparent, stop: 1 #888380);"
-#                           "border-left-color: qlineargradient("
-#                           "x1: 1, y1: 0, x2: 0, y2: 0, "
-#                           "stop: 0 transparent, stop: 1 #888380);"
-#                           "border-top-color: qlineargradient("
-#                           "x1: 0, y1: 1, x2: 0, y2: 0, "
-#                           "stop: 0 transparent, stop: 1 #888380);}")
-                           "border-bottom: 0px;"
-                           "border-left: 0px;"
-                           "border-top: 0px;}")
-        self.setFrameShape(QtGui.QFrame.Shape.NoFrame)
-        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+#                           "stop: 0 #EEEEEE, stop: 0.8 #EEEEEE, "
+#                           "stop: 1 #E4E1E0);"
+#
+##                           "border: 4px solid red;"
+#                           "border-right: 1px solid qlineargradient("
+#                           "x1: 0, y1: 0, x2: 0, y2: 1, "
+#                           "stop: 0 #A8A3A0, stop: 0.8 #A8A3A0, "
+#                           "stop: 0.95 transparent, stop: 1 transparent);"
+##                           "border-bottom-color: qlineargradient("
+##                           "x1: 0, y1: 0, x2: 0, y2: 1, "
+##                           "stop: 0 transparent, stop: 1 #888380);"
+##                           "border-left-color: qlineargradient("
+##                           "x1: 1, y1: 0, x2: 0, y2: 0, "
+##                           "stop: 0 transparent, stop: 1 #888380);"
+##                           "border-top-color: qlineargradient("
+##                           "x1: 0, y1: 1, x2: 0, y2: 0, "
+##                           "stop: 0 transparent, stop: 1 #888380);}")
+#                           "border-bottom: 0px;"
+#                           "border-left: 0px;"
+#                           "border-top: 0px;}")
+        self.setFrameShape(qt.QFrame.NoFrame)
+        self.setAttribute(qt.Qt.WA_DeleteOnClose)
 
     def create_menu(self, display_wgt, groups, sub_groups, ClientObj):
         self.display_wgt = display_wgt
@@ -87,19 +90,19 @@ class LeftMenu(QtGui.QScrollArea):
 #        icon_visible(self._parent.ClientObj.MainWidget, 'Methods', True)
         icon_visible(self._parent.ClientObj.MainWidget, 'Back', True)
         
-        self.widget = QtGui.QWidget (self)
+        self.widget = qt.QWidget (self)
 
-#        self.cur_palette = display_wgt._parent.viewport().palette()
-        self.widget.setPalette(self.cur_palette)
+        #self.cur_palette = display_wgt._parent.viewport().palette()
+        #self.widget.setPalette(self.cur_palette)
 #        self.widget.setStyleSheet("QWidget { background-color: rgb(%s) }" \
 #                        %ClientObj.method_background_color.replace(' ',',',2))
-        self.widget.setStyleSheet("QWidget { background-color: #EEEEEE;}")
+        #self.widget.setStyleSheet("QWidget { background-color: #EEEEEE;}")
 
         self.lable_list = []
         self.button_list = {}
-        self.layout = QtGui.QVBoxLayout(self.widget)
+        self.layout = qt.QVBoxLayout(self.widget)
         
-        self.layout.setAlignment(QtCore.Qt.AlignTop | QtCore.Qt.AlignHCenter)
+        self.layout.setAlignment(qt.Qt.AlignTop | qt.Qt.AlignHCenter)
         
 
         self.group_name = LabelWordWrap(sub_groups[0].split('.')[0], self)
@@ -111,7 +114,7 @@ class LeftMenu(QtGui.QScrollArea):
             'border-radius: 3px;'
         '}')
         
-        self.group_name.setAlignment(QtCore.Qt.AlignHCenter)
+        self.group_name.setAlignment(qt.Qt.AlignHCenter)
         self.layout.addWidget(self.group_name)
         
         for num in range(len(sub_groups)):
@@ -177,12 +180,12 @@ class LeftMenu(QtGui.QScrollArea):
 
     def groupActivated(self, groups, sub_group, title, ClientObj, back = False):
         ClientObj.MainWidget.delete_MainFrameWgt()
-        ClientObj.MainWidget.MainFrameWgt = QtGui.QWidget \
+        ClientObj.MainWidget.MainFrameWgt = qt.QWidget \
                                                     (ClientObj.MainWidget)
 
-        hlayout = QtGui.QHBoxLayout()
-        hlayout.addItem(QtGui.QSpacerItem( 0, 0, \
-            QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding ))  
+        hlayout = qt.QHBoxLayout()
+        hlayout.addItem(qt.QSpacerItem( 0, 0, \
+            qt.QSizePolicy.Expanding, qt.QSizePolicy.Expanding ))  
         ClientObj.MainWidget.MainFrameWgt.setLayout(hlayout)
         
 
@@ -257,25 +260,30 @@ class LeftMenu(QtGui.QScrollArea):
 #        icon_visible(self._parent.ClientObj.MainWidget, 'Methods', True)
         icon_visible(self._parent.ClientObj.MainWidget, 'Back', True)
 
-        self.widget = QtGui.QWidget (self)
-        self.widget.setPalette(self.cur_palette)
+        self.widget = qt.QWidget (self)
+        #--self.widget.setPalette(self.cur_palette)
 
 #        self.widget.setStyleSheet("QWidget { background-color: rgb (%s) }" \
 #                            %self._parent.ClientObj.method_background_color.\
 #                             replace(' ',',',2))
 
+        self.setDisabled(False)
         self.widget.setObjectName('QQQ')
         self.widget.setStyleSheet("QWidget#QQQ { "
-#                                  "background-color: #EEEEEE;}")
-#        self.setStyleSheet("QScrollArea { "
-                           "background-color: qlineargradient("
-                           "x1: 0, y1: 0, x2: 0, y2: 1, "
-                           "stop: 0 #EEEEEE, stop: 0.7 #EEEEEE, "
-                           "stop: 0.9 #E4E1E0, stop: 1 #E4E1E0);}")
+                                  "background-color: %s;}"
+            % get_system_rgb(self, qt.QPalette.Base))
+        #self.setStyleSheet("QScrollArea { "
+        #                   "background-color: qlineargradient("
+        #                   "x1: 0, y1: 0, x2: 0, y2: 1, "
+        #                   "stop: 0 %(start)s, stop: 0.7 %(start)s, "
+        #                   "stop: 0.9 %(end)s, stop: 1 %(end)s);}"%
+        #                   {'start':get_system_rgb(self, qt.QPalette.Base),
+        #                    'end':get_system_rgb(self, qt.QPalette.Window),
+        #                    })
 
         self.button_list = []
-        self.layout = QtGui.QVBoxLayout(self.widget)
-        self.layout.setAlignment(QtCore.Qt.AlignTop | QtCore.Qt.AlignHCenter)
+        self.layout = qt.QVBoxLayout(self.widget)
+        self.layout.setAlignment(qt.Qt.AlignTop | qt.Qt.AlignHCenter)
 #        self.layout.setContentsMargins(28,28,28,0)
         self.layout.setContentsMargins(2,28,2,0)
         self.layout.setSpacing(5)
@@ -287,16 +295,6 @@ class LeftMenu(QtGui.QScrollArea):
         for num_step in range(len(steps)):
             self.button_list.append(StepLabel(steps[num_step], self))
 
-#            if len(icons) > num_step:
-#                themeName = QtGui.QIcon.themeName()
-#                icon = QtGui.QIcon()
-#                icon.setThemeName(themeName)
-#                icon = icon.fromTheme(icons[num_step])
-#                if icon.isNull():
-#                    icon.setThemeName('Tango')
-#                    icon = icon.fromTheme(icons[num_step])
-#                if not icon.isNull():
-#                    self.button_list[num_step].setIcon(icon)
             # collect parameters object
             self.button_list[num_step].clicked.connect(self.collect_object \
                                                       (method_name, num_step))
@@ -307,9 +305,9 @@ class LeftMenu(QtGui.QScrollArea):
 #                            (self.check_step(method_name, num_step))
 
             # calculate button width
-            fmn = QtGui.QFontMetrics(QtGui.QFont('',-1,QtGui.QFont.Normal))
+            fmn = qt.QFontMetrics(qt.QFont('',-1,qt.QFont.Normal))
             normal_width = fmn.width(self.button_list[num_step].text())
-            fmb = QtGui.QFontMetrics(QtGui.QFont('',-1,QtGui.QFont.Bold))
+            fmb = qt.QFontMetrics(qt.QFont('',-1,qt.QFont.Bold))
             bold_width = fmb.width(self.button_list[num_step].text())
 
             diff = bold_width - normal_width + 6
@@ -333,8 +331,8 @@ class LeftMenu(QtGui.QScrollArea):
         self.changed_step(self._parent.ClientObj.param_objects \
                           [method_name]['step'])
 
-#        self.layout.addItem(QtGui.QSpacerItem(100, 100, \
-#                    QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding))
+#        self.layout.addItem(qt.QSpacerItem(100, 100, \
+#                    qt.QSizePolicy.Expanding, qt.QSizePolicy.Expanding))
 
         self.setWidget(self.widget)
 
@@ -347,8 +345,8 @@ class LeftMenu(QtGui.QScrollArea):
             self.show()
 
     # create helper signals
-    collect = QtCore.Signal()
-    calling = QtCore.Signal()
+    collect = qt.Signal()
+    calling = qt.Signal()
 
     def collect_object(self, method_name, set_step = None):
         def wrapper():
@@ -363,15 +361,12 @@ class LeftMenu(QtGui.QScrollArea):
                                                                 change_step:
 #                self.setEnabled(True)
                 return
-            try:
-                self.collect.disconnect()
-            except RuntimeError:
-                pass
 
             self.collect.connect(self._parent.ClientObj.MainWidget.\
-                            MainFrameWgt.collect_object(False))
+                            MainFrameWgt.collect_object())
                             
             self.collect.emit()
+            self.collect.disconnect()
         return wrapper
 
     def calling_method(self, method_name, set_step = None):
@@ -388,13 +383,10 @@ class LeftMenu(QtGui.QScrollArea):
                 self.check_step(method_name, set_step)
 #                self.setEnabled(True)
                 return
-            try:
-                self.calling.disconnect()
-            except RuntimeError:
-                pass
             self.calling.connect(self._parent.ClientObj.MainWidget.\
                           MainFrameWgt.calling(True, from_left_frame = True))
             self.calling.emit()
+            self.calling.disconnect()
             self.check_step(method_name, set_step)
         return wrapper
 
@@ -445,7 +437,7 @@ class LeftMenu(QtGui.QScrollArea):
                 reply = show_question(self._parent, text, informative_text, \
                               not_move = True, title = _('Calculate Console'))
 
-                if reply == QtGui.QMessageBox.No:
+                if reply == qt.QMessageBox.No:
                     self.setEnabled(True)
                     return
 
